@@ -27,7 +27,11 @@ namespace VeraCrypt
 		versionStaticTextFont.SetWeight (wxFONTWEIGHT_BOLD);
 		VersionStaticText->SetFont (versionStaticTextFont);
 
-		VersionStaticText->SetLabel (Application::GetName() + L" " + StringConverter::ToWide (Version::String()));
+		wstring versionStr = StringConverter::ToWide (Version::String());
+#ifdef VC_MACOSX_FUSET
+		versionStr += L" (FUSE-T build)";
+#endif
+		VersionStaticText->SetLabel (Application::GetName() + L" " + versionStr);
 		CopyrightStaticText->SetLabel (TC_STR_RELEASED_BY);
 		WebsiteHyperlink->SetLabel (L"www.idrix.fr");
 
@@ -57,20 +61,20 @@ namespace VeraCrypt
 			L"Paulo Barreto, Brian Gladman, Wei Dai, Peter Gutmann, and many others.\n\n"
 
 			L"Portions of this software:\n"
-			L"Copyright \xA9 2013-2022 IDRIX. All rights reserved.\n"
+			L"Copyright \xA9 2013-2024 IDRIX. All rights reserved.\n"
 			L"Copyright \xA9 2003-2012 TrueCrypt Developers Association. All Rights Reserved.\n"
 			L"Copyright \xA9 1998-2000 Paul Le Roux. All Rights Reserved.\n"
 			L"Copyright \xA9 1998-2008 Brian Gladman. All Rights Reserved.\n"
-			L"Copyright \xA9 1995-2017 Jean-loup Gailly and Mark Adler.\n"
+			L"Copyright \xA9 1995-2023 Jean-loup Gailly and Mark Adler.\n"
 			L"Copyright \xA9 2016 Disk Cryptography Services for EFI (DCS), Alex Kolotnikov.\n"
-			L"Copyright \xA9 1999-2017 Dieter Baron and Thomas Klausner.\n"
+			L"Copyright \xA9 1999-2023 Dieter Baron and Thomas Klausner.\n"
 			L"Copyright \xA9 2013, Alexey Degtyarev. All rights reserved.\n"
 			L"Copyright \xA9 1999-2016 Jack Lloyd. All rights reserved.\n"
 			L"Copyright \xA9 2013-2019 Stephan Mueller <smueller@chronox.de>\n"
-			L"Copyright \xA9 1999-2021 Igor Pavlov\n\n"
+			L"Copyright \xA9 1999-2023 Igor Pavlov\n\n"
 
 			L"\nThis software as a whole:\n"
-			L"Copyright \xA9 2013-2022 IDRIX. All rights reserved.\n\n"
+			L"Copyright \xA9 2013-2024 IDRIX. All rights reserved.\n\n"
 
 			L"This software uses wxWidgets library, which is copyright \xA9 1998-2011 Julian Smart, Robert Roebling et al.\n\n"
 
