@@ -14,6 +14,9 @@
 #include <wx/dynlib.h>
 #ifdef TC_WINDOWS
 #include <wx/msw/registry.h>
+#else
+#include <wx/dir.h>
+#include <wx/arrstr.h>
 #endif
 #include "Common/SecurityToken.h"
 #include "Main/Main.h"
@@ -68,6 +71,87 @@ namespace VeraCrypt
 		}
 		Pkcs5PrfChoice->Select (prfInitialIndex);
 
+		// Language for non-Windows
+#ifndef TC_WINDOWS
+#if defined (TC_MACOSX)
+		wxDir languagesFolder(StringConverter::ToSingle (Application::GetExecutableDirectory()) + "/../Resources/languages/");
+#else
+		wxDir languagesFolder("/usr/share/veracrypt/languages/");
+#endif
+		wxArrayString langArray;
+		LanguageListBox->Append("System default");
+		LanguageListBox->Append("English");
+
+		langEntries = {
+				{"system", L"System default"},
+				{"ar", L"العربية"},
+				{"be", L"Беларуская"},
+				{"bg", L"Български"},
+				{"ca", L"Català"},
+				{"co", L"Corsu"},
+				{"cs", L"Čeština"},
+				{"da", L"Dansk"},
+				{"de", L"Deutsch"},
+				{"el", L"Ελληνικά"},
+				{"en", L"English"},
+				{"es", L"Español"},
+				{"et", L"Eesti"},
+				{"eu", L"Euskara"},
+				{"fa", L"فارسي"},
+				{"fi", L"Suomi"},
+				{"fr", L"Français"},
+				{"he", L"עברית"},
+				{"hu", L"Magyar"},
+				{"id", L"Bahasa Indonesia"},
+				{"it", L"Italiano"},
+				{"ja", L"日本語"},
+				{"ka", L"ქართული"},
+				{"ko", L"한국어"},
+				{"lv", L"Latviešu"},
+				{"nb", L"Norsk Bokmål"},
+				{"nl", L"Nederlands"},
+				{"nn", L"Norsk Nynorsk"},
+				{"pl", L"Polski"},
+				{"ro", L"Română"},
+				{"ru", L"Русский"},
+				{"pt-br", L"Português-Brasil"},
+				{"sk", L"Slovenčina"},
+				{"sl", L"Slovenščina"},
+				{"sv", L"Svenska"},
+				{"th", L"ภาษาไทย"},
+				{"tr", L"Türkçe"},
+				{"uk", L"Українська"},
+				{"uz", L"Ўзбекча"},
+				{"vi", L"Tiếng Việt"},
+				{"zh-cn", L"简体中文"},
+				{"zh-hk", L"繁體中文(香港)"},
+				{"zh-tw", L"繁體中文"}
+		};
+
+		if (wxDir::Exists(languagesFolder.GetName())) {
+			size_t langCount;
+			langCount = wxDir::GetAllFiles(languagesFolder.GetName(), &langArray, "*.xml", wxDIR_FILES);
+			for (size_t i = 0; i < langCount; ++i) {
+				wxFileName filename(langArray[i]);
+
+				// Get the name part of the file (without extension)
+				wxString basename = filename.GetName();
+
+				// Check if the basename matches the pattern "Language.langId"
+				if (basename.StartsWith("Language.")) {
+					wxString langId = basename.AfterFirst('.');
+
+					// Verify if the language ID exists in langEntries map
+					wxString langNative = langEntries[langId];
+					if (!langNative.empty()) {
+						LanguageListBox->Append(langNative);
+					}
+				}
+			}
+		}
+#endif
+
+
 		// Keyfiles
 		TC_CHECK_BOX_VALIDATOR (UseKeyfiles);
 
@@ -238,6 +322,15 @@ namespace VeraCrypt
 		}
 	}
 
+	void PreferencesDialog::OnSysDefaultLangButtonClick (wxCommandEvent& event)
+	{
+		// SetStringSelection()'s Assert currently broken in sorted ListBoxes on macOS, workaround:
+		int itemIndex = LanguageListBox->FindString("System default", true);
+		if (itemIndex != wxNOT_FOUND) {
+			LanguageListBox->SetSelection(itemIndex);
+		}
+	}
+
 	void PreferencesDialog::OnAssignHotkeyButtonClick (wxCommandEvent& event)
 	{
 #ifdef TC_WINDOWS
@@ -355,6 +448,13 @@ namespace VeraCrypt
 		AssignHotkeyButton->Enable (false);
 	}
 
+	// Fixes an issue where going through PreferencesNotebook tabs would unintentionally select the first entry
+	// in the LanguageListBox and thus cause a language change on OKButton press.
+	void PreferencesDialog::OnPageChanged(wxBookCtrlEvent &event)
+	{
+		LanguageListBox->DeselectAll();
+	}
+
 	void PreferencesDialog::OnOKButtonClick (wxCommandEvent& event)
 	{
 #ifdef TC_WINDOWS
@@ -388,6 +488,19 @@ namespace VeraCrypt
 		bool securityTokenModuleChanged = (Preferences.SecurityTokenModule != wstring (Pkcs11ModulePathTextCtrl->GetValue()));
 		Preferences.SecurityTokenModule = wstring (Pkcs11ModulePathTextCtrl->GetValue());
 
+		if (LanguageListBox->GetSelection() != wxNOT_FOUND) {
+			wxString langToFind = LanguageListBox->GetString(LanguageListBox->GetSelection());
+			for (map<wxString, std::wstring>::const_iterator each = langEntries.begin(); each != langEntries.end(); ++each) {
+				if (each->second == langToFind) {
+					Preferences.Language = each->first;
+#ifdef DEBUG
+					cout << "Lang set to: " << each->first << endl;
+#endif
+				}
+			}
+			Gui->ShowInfo (LangString["LINUX_RESTART_FOR_LANGUAGE_CHANGE"]);
+		}
+
 		Gui->SetPreferences (Preferences);
 
 		try
