@@ -23,6 +23,7 @@
 #include "Platform/File.h"
 #include "Platform/StringConverter.h"
 #include <stdio.h>
+#include "UserPreferences.h"
 #endif
 
 namespace VeraCrypt
@@ -39,14 +40,13 @@ namespace VeraCrypt
 		hResL = LoadResource (NULL, hRes);
 		throw_sys_if (!hResL);
 
-		const byte *resPtr = (const byte *) LockResource (hResL);
+		const uint8 *resPtr = (const uint8 *) LockResource (hResL);
 		throw_sys_if (!resPtr);
 
 		return ConstBufferPtr (resPtr, SizeofResource (NULL, hRes));
 	}
 #endif // TC_WINDOWS
 
-
 	string Resources::GetLanguageXml ()
 	{
 #ifdef TC_WINDOWS
@@ -68,66 +68,78 @@ namespace VeraCrypt
 #endif
 		string filenamePost(".xml");
 		string filename = filenamePrefix + defaultLang + filenamePost;
-		if(const char* env_p = getenv("LANG")){
-		    string lang(env_p);
+
+		UserPreferences Preferences;
+		Preferences.Load();
+		string preferredLang = string(Preferences.Language.begin(), Preferences.Language.end());
 #ifdef DEBUG
-			std::cout << lang << std::endl;
+		std::cout << "Config language: " << preferredLang << std::endl;
 #endif
-			if ( lang.size() > 1 ){
-				int found = lang.find(".");
-				if ( found > 1 ){
-					string langTag = lang.substr (0,found);
-					string lowerLangTag(StringConverter::ToLower (langTag) );
-					int foundUnderscore = lowerLangTag.find("_");
-					if ( foundUnderscore > 0 ) {
-						lowerLangTag.replace(foundUnderscore,1,1,'-');
-						filename = filenamePrefix + lowerLangTag + filenamePost;
-						FilesystemPath xml(filename);
-						if (! xml.IsFile()){
-							string shortLangTag = lowerLangTag.substr(0,foundUnderscore);
-							filename = filenamePrefix + shortLangTag + filenamePost;
+
+		if (preferredLang == "system") {
+			if (const char *env_p = getenv("LANG")) {
+				string lang(env_p);
+#ifdef DEBUG
+				std::cout << "env $LANG: " << lang << std::endl;
+#endif
+				if (lang.size() > 1) {
+					int found = lang.find(".");
+					if (found > 1) {
+						string langTag = lang.substr(0, found);
+						string lowerLangTag(StringConverter::ToLower(langTag));
+						int foundUnderscore = lowerLangTag.find("_");
+						if (foundUnderscore > 0) {
+							lowerLangTag.replace(foundUnderscore, 1, 1, '-');
+							filename = filenamePrefix + lowerLangTag + filenamePost;
 							FilesystemPath xml(filename);
-							if (! xml.IsFile()){
+							if (!xml.IsFile()) {
+								string shortLangTag = lowerLangTag.substr(0, foundUnderscore);
+								filename = filenamePrefix + shortLangTag + filenamePost;
+								FilesystemPath xml(filename);
+								if (!xml.IsFile()) {
+									filename = filenamePrefix + defaultLang + filenamePost;
+								}
+							}
+						} else {
+							filename = filenamePrefix + langTag + filenamePost;
+							FilesystemPath xml(filename);
+							if (!xml.IsFile()) {
 								filename = filenamePrefix + defaultLang + filenamePost;
 							}
 						}
-					}else{
-						filename = filenamePrefix + langTag + filenamePost;
+					} else {
+						string lowerLang(StringConverter::ToLower(lang));
+						filename = filenamePrefix + lowerLang + filenamePost;
 						FilesystemPath xml(filename);
-						if (! xml.IsFile()){
-							filename = filenamePrefix + defaultLang + filenamePost;
-						}
-					}
-				}else{
-					string lowerLang(StringConverter::ToLower (lang) );
-					filename = filenamePrefix + lowerLang + filenamePost;
-					FilesystemPath xml(filename);
-					if (! xml.IsFile()){
-						int foundUnderscore = lowerLang.find("_");
-						if ( foundUnderscore > 0 ) {
-							lowerLang.replace(foundUnderscore,1,1,'-');
-							filename = filenamePrefix + lowerLang + filenamePost;
-							FilesystemPath xml(filename);
-							if (! xml.IsFile()){
-								filename = filenamePrefix + defaultLang + filenamePost;
+						if (!xml.IsFile()) {
+							int foundUnderscore = lowerLang.find("_");
+							if (foundUnderscore > 0) {
+								lowerLang.replace(foundUnderscore, 1, 1, '-');
+								filename = filenamePrefix + lowerLang + filenamePost;
+								FilesystemPath xml(filename);
+								if (!xml.IsFile()) {
+									filename = filenamePrefix + defaultLang + filenamePost;
+								}
 							}
 						}
 					}
 				}
 			}
+		} else {
+			filename = filenamePrefix + preferredLang + filenamePost;
 		}
 		FilesystemPath xml(filename);
 		if ( xml.IsFile() ){
 			File file;
 			file.Open (xml, File::OpenRead, File::ShareRead);
-			vector <byte> keyfileData (file.Length());
+			vector <uint8> keyfileData (file.Length());
 			BufferPtr keyfileDataBuf (&keyfileData.front(), keyfileData.size());
 			file.ReadCompleteBuffer (keyfileDataBuf);
 			file.Close();
 			string langxml(keyfileData.begin(), keyfileData.end());
 			return langxml;
 		}
-		static byte LanguageXml[] =
+		static uint8 LanguageXml[] =
 		{
 #			include "Common/Language.xml.h"
 			, 0
@@ -146,7 +158,7 @@ namespace VeraCrypt
 		strBuf.CopyFrom (res);
 		return string (reinterpret_cast <char *> (strBuf.Ptr()));
 #else
-		static byte License[] =
+		static uint8 License[] =
 		{
 #			include "License.txt.h"
 			, 0
@@ -164,7 +176,7 @@ namespace VeraCrypt
 #ifdef TC_WINDOWS
 		return wxBitmap (L"IDB_DRIVE_ICON", wxBITMAP_TYPE_BMP_RESOURCE).ConvertToImage().Resize (wxSize (16, 12), wxPoint (0, 0));
 #else
-		static const byte DriveIcon[] =
+		static const uint8 DriveIcon[] =
 		{
 #			include "Mount/Drive_icon_96dpi.bmp.h"
 		};
@@ -180,7 +192,7 @@ namespace VeraCrypt
 		wxImage image = wxBitmap (L"IDB_DRIVE_ICON_MASK", wxBITMAP_TYPE_BMP_RESOURCE).ConvertToImage().Resize (wxSize (16, 12), wxPoint (0, 0));
 		return wxBitmap (image.ConvertToMono (0, 0, 0), 1);
 #else
-		static const byte DriveIconMask[] =
+		static const uint8 DriveIconMask[] =
 		{
 #			include "Mount/Drive_icon_mask_96dpi.bmp.h"
 		};
@@ -189,7 +201,7 @@ namespace VeraCrypt
 		wxImage image (stream);
 		image.Resize (wxSize (16, 12), wxPoint (0, 0));
 
-#	ifdef __WXGTK__
+#	if defined  __WXGTK__ || defined TC_MACOSX
 		return wxBitmap (image.ConvertToMono (0, 0, 0), 1);
 #	else
 		return wxBitmap (image);
@@ -203,7 +215,7 @@ namespace VeraCrypt
 #ifdef TC_WINDOWS
 		return wxBitmap (L"IDB_LOGO", wxBITMAP_TYPE_BMP_RESOURCE);
 #else
-		static const byte Logo[] =
+		static const uint8 Logo[] =
 		{
 #			include "Mount/Logo_96dpi.bmp.h"
 		};
@@ -218,7 +230,7 @@ namespace VeraCrypt
 #ifdef TC_WINDOWS
 		return wxBitmap (L"IDB_TEXTUAL_LOGO", wxBITMAP_TYPE_BMP_RESOURCE);
 #else
-		static const byte Logo[] =
+		static const uint8 Logo[] =
 		{
 #			include "Common/Textual_logo_96dpi.bmp.h"
 		};
@@ -243,7 +255,7 @@ namespace VeraCrypt
 #ifdef TC_WINDOWS
 		return wxBitmap (L"IDB_VOLUME_WIZARD_BITMAP", wxBITMAP_TYPE_BMP_RESOURCE);
 #else
-		static const byte VolumeWizardIcon[] =
+		static const uint8 VolumeWizardIcon[] =
 		{
 #			include "Format/VeraCrypt_Wizard.bmp.h"
 		};
