@@ -92,6 +92,7 @@ namespace VeraCrypt
 			TC_CONFIG_SET (BackgroundTaskEnabled);
 			if (configMap.count(L"FilesystemOptions") > 0) { SetValue (configMap[L"FilesystemOptions"], DefaultMountOptions.FilesystemOptions); configMap.erase (L"FilesystemOptions"); }
 			TC_CONFIG_SET (ForceAutoDismount);
+			TC_CONFIG_SET (Language);
 			TC_CONFIG_SET (LastSelectedSlotNumber);
 			TC_CONFIG_SET (MaxVolumeIdleTime);
 			TC_CONFIG_SET (MountDevicesOnLogon);
@@ -214,6 +215,7 @@ namespace VeraCrypt
 		TC_CONFIG_ADD (BackgroundTaskEnabled);
 		formatter.AddEntry (L"FilesystemOptions", DefaultMountOptions.FilesystemOptions);
 		TC_CONFIG_ADD (ForceAutoDismount);
+		TC_CONFIG_ADD (Language);
 		TC_CONFIG_ADD (LastSelectedSlotNumber);
 		TC_CONFIG_ADD (MaxVolumeIdleTime);
 		TC_CONFIG_ADD (MountDevicesOnLogon);
@@ -240,7 +242,7 @@ namespace VeraCrypt
 		for (map<wxString, wxString>::const_iterator it = UnknownConfigMapEntries.begin(); it != UnknownConfigMapEntries.end(); ++it)
 		{
 			formatter.AddEntry(it->first.c_str(), it->second);
-		}		
+		}
 
 		XmlWriter writer (Application::GetConfigFilePath (GetPreferencesFileName(), true));
 		writer.WriteNode (formatter.XmlConfig);
