@@ -24,10 +24,10 @@ namespace VeraCrypt
 		EncryptionModeXTS () { }
 		virtual ~EncryptionModeXTS () { }
 
-		virtual void Decrypt (byte *data, uint64 length) const;
-		virtual void DecryptSectorsCurrentThread (byte *data, uint64 sectorIndex, uint64 sectorCount, size_t sectorSize) const;
-		virtual void Encrypt (byte *data, uint64 length) const;
-		virtual void EncryptSectorsCurrentThread (byte *data, uint64 sectorIndex, uint64 sectorCount, size_t sectorSize) const;
+		virtual void Decrypt (uint8 *data, uint64 length) const;
+		virtual void DecryptSectorsCurrentThread (uint8 *data, uint64 sectorIndex, uint64 sectorCount, size_t sectorSize) const;
+		virtual void Encrypt (uint8 *data, uint64 length) const;
+		virtual void EncryptSectorsCurrentThread (uint8 *data, uint64 sectorIndex, uint64 sectorCount, size_t sectorSize) const;
 		virtual const SecureBuffer &GetKey () const { return SecondaryKey; }
 		virtual size_t GetKeySize () const;
 		virtual wstring GetName () const { return L"XTS"; };
@@ -36,10 +36,10 @@ namespace VeraCrypt
 		virtual void SetKey (const ConstBufferPtr &key);
 
 	protected:
-		void DecryptBuffer (byte *data, uint64 length, uint64 startDataUnitNo) const;
-		void DecryptBufferXTS (const Cipher &cipher, const Cipher &secondaryCipher, byte *buffer, uint64 length, uint64 startDataUnitNo, unsigned int startCipherBlockNo) const;
-		void EncryptBuffer (byte *data, uint64 length, uint64 startDataUnitNo) const;
-		void EncryptBufferXTS (const Cipher &cipher, const Cipher &secondaryCipher, byte *buffer, uint64 length, uint64 startDataUnitNo, unsigned int startCipherBlockNo) const;
+		void DecryptBuffer (uint8 *data, uint64 length, uint64 startDataUnitNo) const;
+		void DecryptBufferXTS (const Cipher &cipher, const Cipher &secondaryCipher, uint8 *buffer, uint64 length, uint64 startDataUnitNo, unsigned int startCipherBlockNo) const;
+		void EncryptBuffer (uint8 *data, uint64 length, uint64 startDataUnitNo) const;
+		void EncryptBufferXTS (const Cipher &cipher, const Cipher &secondaryCipher, uint8 *buffer, uint64 length, uint64 startDataUnitNo, unsigned int startCipherBlockNo) const;
 		void SetSecondaryCipherKeys ();
 
 		SecureBuffer SecondaryKey;
